<script setup>
import { computed, ref, reactive, onMounted, onUnmounted } from 'vue';

const props = defineProps({
    position: {
        type: String,
        default: 'right',
    },
    marginTop: {
        type: String,
        default: '0px',
    },
    marginLeft: {
        type: String,
        default: '0px',
    },
    marginRight: {
        type: String,
        default: '0px',
    },
});

const positionClasses = computed(() => {
    if (props.position === 'left') {
        return 'origin-top-left left-0';
    }

    if (props.position === 'right') {
        return 'origin-top-right right-0';
    }

    return 'origin-top inset-x-0';
});

const marginStyles = computed(() => {
    return reactive({
        marginTop: props.marginTop,
        marginLeft: props.marginLeft,
        marginRight: props.marginRight
    });
});

let open = ref(false);

const closeOnEscape = (e) => {
    if (open.value && e.key === 'Escape') {
        open.value = false;
    }
};

onMounted(() => document.addEventListener('keydown', closeOnEscape));
onUnmounted(() => document.removeEventListener('keydown', closeOnEscape));

</script>

<style scoped>
.active{
    border-bottom-width: 1px;
    border-bottom-style: solid;
    box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);
    font-weight: 600;
}
</style>

<template>
    <div class="relative h-full">
        <div @click="open = ! open" class="h-full w-full cursor-pointer">
            <slot name="head"/>
        </div>

        <div v-show="open" @click="open = false" class="rounded-md bg-navBar absolute flex flex-col justify-start items-start gap-y-0.5 z-[11] cursor-pointer min-w-[8rem]" :class="[positionClasses]" :style="[marginStyles]">
            <slot name="body"/>
        </div>
    </div>
    <div class="top-0 bottom-0 left-0 right-0 absolute z-10" v-if="open" @click="open = false"/>
</template>

<script>
export default {
    data() {
        return {
        };
    },
    methods: {
    },
}
</script>